@@ -1,3 +1,5 @@
+use crate::binary::Value as BValue;
+
 #[derive(Clone, Debug)]
 pub enum Credentials {
     AccessToken(String),
@@ -5,12 +7,21 @@ pub enum Credentials {
 }
 
 impl Credentials {
-    pub fn to_vec(&self) -> Vec<(&str, &str)> {
+    pub fn to_http_params(&self) -> Vec<(&str, String)> {
         match self {
-            Self::AccessToken(value) => vec![("access_token", value.as_str())],
+            Self::AccessToken(value) => vec![("access_token", value.clone())],
             Self::UserPassword { username, password } => vec![
-                ("username", username.as_str()),
-                ("password", password.as_str()),
+                ("username", username.clone()),
+                ("password", password.clone()),
+            ],
+        }
+    }
+    pub fn to_binary_params(&self) -> Vec<(&str, BValue)> {
+        match self {
+            Self::AccessToken(value) => vec![("access_token", BValue::Text(value.clone()))],
+            Self::UserPassword { username, password } => vec![
+                ("username", BValue::Text(username.clone())),
+                ("password", BValue::Text(password.clone())),
             ],
         }
     }
